@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Sequence
 
 from .literals import (
     AttackLayerType,
@@ -125,7 +125,7 @@ AssociateHealthCheckRequestRequestTypeDef = TypedDict(
 AssociateProactiveEngagementDetailsRequestRequestTypeDef = TypedDict(
     "AssociateProactiveEngagementDetailsRequestRequestTypeDef",
     {
-        "EmergencyContactList": List["EmergencyContactTypeDef"],
+        "EmergencyContactList": Sequence["EmergencyContactTypeDef"],
     },
 )
 
@@ -234,8 +234,8 @@ _OptionalCreateProtectionGroupRequestRequestTypeDef = TypedDict(
     "_OptionalCreateProtectionGroupRequestRequestTypeDef",
     {
         "ResourceType": ProtectedResourceTypeType,
-        "Members": List[str],
-        "Tags": List["TagTypeDef"],
+        "Members": Sequence[str],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -258,7 +258,7 @@ _RequiredCreateProtectionRequestRequestTypeDef = TypedDict(
 _OptionalCreateProtectionRequestRequestTypeDef = TypedDict(
     "_OptionalCreateProtectionRequestRequestTypeDef",
     {
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -428,7 +428,7 @@ LimitTypeDef = TypedDict(
 ListAttacksRequestRequestTypeDef = TypedDict(
     "ListAttacksRequestRequestTypeDef",
     {
-        "ResourceArns": List[str],
+        "ResourceArns": Sequence[str],
         "StartTime": "TimeRangeTypeDef",
         "EndTime": "TimeRangeTypeDef",
         "NextToken": str,
@@ -704,7 +704,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -730,14 +730,14 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
 UpdateEmergencyContactSettingsRequestRequestTypeDef = TypedDict(
     "UpdateEmergencyContactSettingsRequestRequestTypeDef",
     {
-        "EmergencyContactList": List["EmergencyContactTypeDef"],
+        "EmergencyContactList": Sequence["EmergencyContactTypeDef"],
     },
     total=False,
 )
@@ -754,7 +754,7 @@ _OptionalUpdateProtectionGroupRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateProtectionGroupRequestRequestTypeDef",
     {
         "ResourceType": ProtectedResourceTypeType,
-        "Members": List[str],
+        "Members": Sequence[str],
     },
     total=False,
 )
